/*
    Copyright (C) 2005-2008  Michel de Boer <michel@twinklephone.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "coding.h"
#include "util.h"

t_coding::t_coding() {
	q = 1.0;
}

t_coding::t_coding(const string &s) {
	q = 1.0;
	content_coding = s;
}

string t_coding::encode(void) const {
	string s;

	s = content_coding;
	
	if (q != 1.0) {
		s += ";q=";
		s += float2str(q, 1);
	}

	return s;
}
